==> py-citus-loader-1.0.5.tar.gz: py-citus-loader-1.0.5/citus_dump/classes.py <==
import os.path


class Coordinator:
    def __init__(self, connection_string, nodes, configuration):
        self.nodes = nodes
        self.distributed_tables = None
        self.reference_tables = None
        self.connection_string = connection_string
        self.configuration = configuration

    @property
    def distributed_shards(self):
        if not self.distributed_tables:
            return None
        distributed_shards = []
        for table in self.distributed_tables:
            distributed_shards += table.shards

        return distributed_shards

    @property
    def dump_data_file(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_data_dump')

    def dump_files_exist(self):
        if not self.dump_data_file:
            return False

        for node in self.nodes:
            if not node.dump_file_exist():
                return False

        if not os.path.exists(self.dump_data_file):
            print('%s does not exist' % self.dump_data_file)
            return False

        return True

    @property
    def distribute_statements(self):
        statements = []

        for table in self.distributed_tables:
            statements.append("SELECT create_distributed_table('%s', '%s');\n"
                              % (table.name,
                                 table.distribution_column))


        return statements

    @property
    def reference_statements(self):
        statements = []

        for table in self.reference_tables:
            statements.append("SELECT create_reference_table('%s');\n"
                              % table.name)

        return statements

    @property
    def schema_dump_path(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_schema.sql')

    @property
    def distribute_path(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_distribute.sql')

    @property
    def sequences_dump_path(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_sequences.sql')

    @property
    def schema_dump_statement(self):
        return '%s --no-owner --format=plain --schema-only -T pg_catalog.* --file=%s %s' % (
            self.configuration.pg_dump,
            self.schema_dump_path,
            self.connection_string)

    @property
    def data_dump_statement(self):
        command = "%s -d '%s' -Fd -j %d -f %s --data-only" % (self.configuration.pg_dump,
                                                              self.connection_string,
                                                              self.configuration.dump_jobs,
                                                              self.dump_data_file)

        for distributed_table in self.distributed_tables:
            command += ' -T %s' % distributed_table.name

        return command

    @property
    def pg_restore_statement(self):
        command = "%s --no-acl --no-owner --data-only -j %d -d '%s' %s --disable-triggers"

        return command % (self.configuration.pg_restore, self.configuration.restore_jobs,
                          self.connection_string, self.dump_data_file)


    @property
    def lock_statements(self):
        statements = []

        for table in self.distributed_tables + self.reference_tables:
            statements.append('LOCK TABLE %s IN EXCLUSIVE MODE;' % table.name)

        return statements


class Node:
    def __init__(self, name, port, connection_string):
        self.name = name
        self.port = port
        self.formation = None
        self.coordinator = None
        self.shards = []
        self.connection_string = connection_string

    def set_coordinator(self, coordinator):
        self.coordinator = coordinator

    def set_formation(self, formation):
        self.coordinator = formation

    def set_shards(self, shards):
        self.shards = shards

    def add_shard(self, shard):
        self.shards.append(shard)

    def dump_file_exist(self):
        if not os.path.exists(self.dump_file):
            print('%s does not exist' % self.dump_file)
            return False

        return True

    @property
    def dump_file(self):
        return os.path.join(self.coordinator.configuration.dump_folder,
                            '%s_dump' % (self.name))

    @property
    def dump_statement(self):
        return  "%(pg_dump)s -d '%(host)s' -Fd -j %(jobs)d -f %(path)s" % {
            'pg_dump': self.coordinator.configuration.pg_dump,
            'host': self.connection_string,
            'path': self.dump_file,
            'jobs': self.coordinator.configuration.dump_jobs
        }



class Table:
    def __init__(self, name, is_reference=False,
                 is_distributed=False,
                 distribution_column=None,
                 shards=None):
        self.name = name
        self.is_reference = is_reference
        self.is_distributed = is_distributed
        self.distribution_column = distribution_column
        self.shards = shards

    def set_shards(self, shards):
        self.shards = shards


class Shard:
    def __init__(self, id, node, table, min_value, max_value):
        self.id = id
        self.node = node
        self.table = table
        self.min_value = min_value
        self.max_value = max_value
        self.future_shard = None
        self.old_shard = None

    def set_future_shard(self, shard):
        self.future_shard = shard

    def set_old_shard(self, shard):
        self.old_shard = shard

==> py-citus-loader-1.0.8.tar.gz: py-citus-loader-1.0.8/citus_dump/classes.py <==
import os.path


class Coordinator:
    def __init__(self, connection_string, nodes, configuration):
        self.nodes = nodes
        self.distributed_tables = None
        self.reference_tables = None
        self.connection_string = connection_string
        self.configuration = configuration

    @property
    def distributed_shards(self):
        if not self.distributed_tables:
            return None
        distributed_shards = []
        for table in self.distributed_tables:
            distributed_shards += table.shards

        return distributed_shards

    @property
    def dump_data_file(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_data_dump')

    def dump_files_exist(self):
        if not self.dump_data_file:
            return False

        for node in self.nodes:
            if not node.dump_file_exist():
                return False

        if not os.path.exists(self.dump_data_file):
            print('%s does not exist' % self.dump_data_file)
            return False

        return True

    @property
    def distribute_statements(self):
        statements = []

        for table in self.distributed_tables:
            statements.append("SELECT create_distributed_table('%s', '%s');\n"
                              % (table.name,
                                 table.distribution_column))


        return statements

    @property
    def reference_statements(self):
        statements = []

        for table in self.reference_tables:
            statements.append("SELECT create_reference_table('%s');\n"
                              % table.name)

        return statements

    @property
    def schema_dump_path(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_schema.sql')

    @property
    def distribute_path(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_distribute.sql')

    @property
    def sequences_dump_path(self):
        return os.path.join(self.configuration.dump_folder, 'coordinator_sequences.sql')

    @property
    def schema_dump_statement(self):
        return '%s --no-owner --format=plain --schema-only -T pg_catalog.* -N cron --file=%s %s' % (
            self.configuration.pg_dump,
            self.schema_dump_path,
            self.connection_string)

    @property
    def data_dump_statement(self):
        command = "%s -d '%s' -Fd -j %d -f %s --data-only" % (self.configuration.pg_dump,
                                                              self.connection_string,
                                                              self.configuration.dump_jobs,
                                                              self.dump_data_file)

        for distributed_table in self.distributed_tables:
            command += ' -T %s' % distributed_table.name

        command += ' -N cron'

        return command

    @property
    def pg_restore_statement(self):
        command = "%s --no-acl --no-owner --data-only -j %d -d '%s' %s --disable-triggers"

        return command % (self.configuration.pg_restore, self.configuration.restore_jobs,
                          self.connection_string, self.dump_data_file)


    @property
    def lock_statements(self):
        statements = []

        for table in self.distributed_tables + self.reference_tables:
            statements.append('LOCK TABLE %s IN EXCLUSIVE MODE;' % table.name)

        return statements


class Node:
    def __init__(self, name, port, connection_string):
        self.name = name
        self.port = port
        self.formation = None
        self.coordinator = None
        self.shards = []
        self.connection_string = connection_string

    def set_coordinator(self, coordinator):
        self.coordinator = coordinator

    def set_formation(self, formation):
        self.coordinator = formation

    def set_shards(self, shards):
        self.shards = shards

    def add_shard(self, shard):
        self.shards.append(shard)

    def dump_file_exist(self):
        if not os.path.exists(self.dump_file):
            print('%s does not exist' % self.dump_file)
            return False

        return True

    @property
    def dump_file(self):
        return os.path.join(self.coordinator.configuration.dump_folder,
                            '%s_dump' % (self.name))

    @property
    def dump_statement(self):
        return  "%(pg_dump)s -d '%(host)s' -Fd -j %(jobs)d -N cron -f %(path)s" % {
            'pg_dump': self.coordinator.configuration.pg_dump,
            'host': self.connection_string,
            'path': self.dump_file,
            'jobs': self.coordinator.configuration.dump_jobs
        }



class Table:
    def __init__(self, name, is_reference=False,
                 is_distributed=False,
                 distribution_column=None,
                 shards=None):
        self.name = name
        self.is_reference = is_reference
        self.is_distributed = is_distributed
        self.distribution_column = distribution_column
        self.shards = shards

    def set_shards(self, shards):
        self.shards = shards


class Shard:
    def __init__(self, id, node, table, min_value, max_value):
        self.id = id
        self.node = node
        self.table = table
        self.min_value = min_value
        self.max_value = max_value
        self.future_shard = None
        self.old_shard = None

    def set_future_shard(self, shard):
        self.future_shard = shard

    def set_old_shard(self, shard):
        self.old_shard = shard
